'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _semanticUiReact = require('semantic-ui-react');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Default Semantic element to select a field for a Rule in the QueryBuilderSemantic
 */
var FieldSelectorSemantic = function FieldSelectorSemantic(props) {
  var value = props.value,
      options = props.options,
      className = props.className,
      handleOnChange = props.handleOnChange,
      title = props.title,
      ruleSemanticProps = props.ruleSemanticProps;

  return _react2.default.createElement(_semanticUiReact.Dropdown, Object.assign({}, ruleSemanticProps.fieldSelector, {
    title: title,
    className: className,
    options: options,
    defaultValue: value,
    onChange: function onChange(e, _ref) {
      var value = _ref.value;
      return handleOnChange(value);
    }
  }));
};

FieldSelectorSemantic.displayName = 'FieldSelectorSemantic';

FieldSelectorSemantic.propTypes = {
  /**
   * Semantic Props for fieldSelector on a rule
   */
  ruleSemanticProps: _propTypes2.default.shape({
    /**
     * Semantic Dropdown props on a rule
     * https://react.semantic-ui.com/modules/dropdown/
     */
    fieldSelector: _propTypes2.default.any
  }),
  /**
   * selected field from the existing query representation, if any
   */
  value: _propTypes2.default.string,
  /**
   *
   */
  options: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    text: _propTypes2.default.string.isRequired,
    value: _propTypes2.default.string.isRequired,
    key: _propTypes2.default.string
  })).isRequired,
  /**
   * //css className to be applied
   */
  className: _propTypes2.default.string,
  /**
   * callback function to invoke when the element changes
   */
  handleOnChange: _propTypes2.default.func,
  /**
   * html title
   */
  title: _propTypes2.default.string
};

exports.default = FieldSelectorSemantic;